oae

module
v0.0.0-...-249dd9b Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 22, 2026 License: BSD-3-Clause

README

Documentation License

oae

a STREAM & CHAIN Contruction Online Authenticated Encryption package

Description

Online Authenticate Encryption and its nonce reuse misuse resistance

standard library based package to provide "online" authenticated encryption reader / writer facilities using STREAM & CHAIN construction using any cipher.AEAD.

How to use

This is WORK IN PROGRESS... reliable code should come shortly as we need it.

The API is still being worked, especially with AD.

STREAM is in, CHAIN is starting.

import (
	"ermites.io/x/oae/stream"
	"ermites.io/x/oae/chain"
)

func main() {
..
	// STREAM construction
	stw, err := stream.NewWriter(w, aead, nonce, ad, 32768) // you get an io.Writer
	str, err := stream.NewReader(r, aead, nonce, ad, 32768) // you get an io.Reader

	// CHAIN construction

Directories

Path Synopsis
Package chain implements the CHAIN online authenticated-encryption construction from "Online Authenticated-Encryption and its Nonce-Reuse Misuse-Resistance" (Hoang, Reyhanitabar, Rogaway, Vizár – CRYPTO 2015).
Package chain implements the CHAIN online authenticated-encryption construction from "Online Authenticated-Encryption and its Nonce-Reuse Misuse-Resistance" (Hoang, Reyhanitabar, Rogaway, Vizár – CRYPTO 2015).
cmd
oaep command
Package stream implements the STREAM online authenticated-encryption construction from "Online Authenticated-Encryption and its Nonce-Reuse Misuse-Resistance" (Hoang, Reyhanitabar, Rogaway, Vizár – CRYPTO 2015).
Package stream implements the STREAM online authenticated-encryption construction from "Online Authenticated-Encryption and its Nonce-Reuse Misuse-Resistance" (Hoang, Reyhanitabar, Rogaway, Vizár – CRYPTO 2015).

Jump to